==> activity-common-api-1.3.21.xxd-sources.jar: cn/com/duiba/activity/common/center/api/dto/wallet/RedAccPeriodRelDto.java <==
package cn.com.duiba.activity.common.center.api.dto.wallet;

import cn.com.duiba.activity.common.center.api.enums.RedAccPeriodRelTypeEnum;

import java.util.Date;

/**
 * Created by xiaoxuda on 2018/12/13.
 */
public class RedAccPeriodRelDto implements java.io.Serializable {
	private static final long serialVersionUID = 5454155825314635342L;
	
	/**id**/
	private Long id;
	
	/**周期ID**/
	private Long periodId;
	
	/**业务类型**/
	private RedAccPeriodRelTypeEnum relType;
	
	/**业务ID**/
	private Long relId;
	
	/**业务状态，0：关闭，1：开启**/
	private Boolean relStatus;
	
	/**奖金额度**/
	private Integer bonusLimit;
	
	/**提现门槛**/
	private Integer withdrawThreshold;
	
	/**记录创建时间**/
	private Date gmtCreate;
	
	/**记录修改时间**/
	private Date gmtModified;
	

	public void setId(Long value) {
		this.id = value;
	}
	
	public Long getId() {
		return this.id;
	}
	public void setPeriodId(Long value) {
		this.periodId = value;
	}
	
	public Long getPeriodId() {
		return this.periodId;
	}

	public RedAccPeriodRelTypeEnum getRelType() {
		return relType;
	}

	public void setRelType(RedAccPeriodRelTypeEnum relType) {
		this.relType = relType;
	}

	public void setRelId(Long value) {
		this.relId = value;
	}
	
	public Long getRelId() {
		return this.relId;
	}
	public void setRelStatus(Boolean value) {
		this.relStatus = value;
	}
	
	public Boolean getRelStatus() {
		return this.relStatus;
	}
	public void setBonusLimit(Integer value) {
		this.bonusLimit = value;
	}
	
	public Integer getBonusLimit() {
		return this.bonusLimit;
	}
	public void setWithdrawThreshold(Integer value) {
		this.withdrawThreshold = value;
	}
	
	public Integer getWithdrawThreshold() {
		return this.withdrawThreshold;
	}
	public void setGmtCreate(Date value) {
		this.gmtCreate = value;
	}
	
	public Date getGmtCreate() {
		return this.gmtCreate;
	}
	public void setGmtModified(Date value) {
		this.gmtModified = value;
	}
	
	public Date getGmtModified() {
		return this.gmtModified;
	}

}

==> activity-common-api-1.3.25.xxd-sources.jar: cn/com/duiba/activity/common/center/api/dto/wallet/RedAccPeriodRelDto.java <==
package cn.com.duiba.activity.common.center.api.dto.wallet;

import cn.com.duiba.activity.common.center.api.enums.RedAccPeriodRelTypeEnum;

import java.util.Date;

/**
 * Created by xiaoxuda on 2018/12/13.
 */
public class RedAccPeriodRelDto implements java.io.Serializable {
	private static final long serialVersionUID = 5454155825314635342L;
	
	/**id**/
	private Long id;
	
	/**周期ID**/
	private Long periodId;
	
	/**业务类型**/
	private RedAccPeriodRelTypeEnum relType;
	
	/**业务ID**/
	private Long relId;
	
	/**业务状态，0：关闭，1：开启**/
	private Boolean relStatus;
	
	/**奖金额度**/
	private Long bonusLimit;

	/**
	 * 中奖人数限制
	 */
	private Long winnerLimit;
	
	/**提现门槛**/
	private Long withdrawThreshold;
	
	/**记录创建时间**/
	private Date gmtCreate;
	
	/**记录修改时间**/
	private Date gmtModified;
	

	public void setId(Long value) {
		this.id = value;
	}
	
	public Long getId() {
		return this.id;
	}
	public void setPeriodId(Long value) {
		this.periodId = value;
	}
	
	public Long getPeriodId() {
		return this.periodId;
	}

	public RedAccPeriodRelTypeEnum getRelType() {
		return relType;
	}

	public void setRelType(RedAccPeriodRelTypeEnum relType) {
		this.relType = relType;
	}

	public void setRelId(Long value) {
		this.relId = value;
	}
	
	public Long getRelId() {
		return this.relId;
	}
	public void setRelStatus(Boolean value) {
		this.relStatus = value;
	}
	
	public Boolean getRelStatus() {
		return this.relStatus;
	}
	public void setBonusLimit(Long value) {
		this.bonusLimit = value;
	}
	
	public Long getBonusLimit() {
		return this.bonusLimit;
	}

	public Long getWinnerLimit() {
		return winnerLimit;
	}

	public void setWinnerLimit(Long winnerLimit) {
		this.winnerLimit = winnerLimit;
	}

	public void setWithdrawThreshold(Long value) {
		this.withdrawThreshold = value;
	}
	
	public Long getWithdrawThreshold() {
		return this.withdrawThreshold;
	}
	public void setGmtCreate(Date value) {
		this.gmtCreate = value;
	}
	
	public Date getGmtCreate() {
		return this.gmtCreate;
	}
	public void setGmtModified(Date value) {
		this.gmtModified = value;
	}
	
	public Date getGmtModified() {
		return this.gmtModified;
	}

}
